# Copyright (C) 2012-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Archive commands for the plzip program."""

from . import (
    extract_singlefile_standard,
    test_singlefile_standard,
    create_singlefile_standard,
)


extract_lzip = extract_singlefile_standard
test_lzip = test_singlefile_standard
create_lzip = create_singlefile_standard



# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Archive commands for the dpkg-deb program."""


def extract_deb(archive, compression, cmd, verbosity, interactive, outdir):
    """Extract a DEB archive."""
    cmdlist = [cmd]
    if verbosity > 1:
        cmdlist.append('--vextract')
    else:
        cmdlist.append('--extract')
    cmdlist.extend(['--', archive, outdir])
    return cmdlist


def list_deb(archive, compression, cmd, verbosity, interactive):
    """List a DEB archive."""
    return [cmd, '--contents', '--', archive]


test_deb = list_deb



# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Archive commands for the rzip program."""

from .. import fileutil


def extract_rzip(archive, compression, cmd, verbosity, interactive, outdir):
    """Extract an RZIP archive."""
    cmdlist = [cmd, '-d', '-k']
    if verbosity > 1:
        cmdlist.append('-v')
    outfile = fileutil.get_single_outfile(outdir, archive)
    cmdlist.extend(["-o", outfile, archive])
    return cmdlist


def create_rzip(archive, compression, cmd, verbosity, interactive, filenames):
    """Create an RZIP archive."""
    cmdlist = [cmd, '-k', '-o', archive]
    if verbosity > 1:
        cmdlist.append('-v')
    cmdlist.extend(filenames)
    return cmdlist



# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Archive commands for the uncompress.real program."""

from .. import util, fileutil


def extract_compress(archive, compression, cmd, verbosity, interactive, outdir):
    """Extract a compressed archive."""
    cmdlist = [util.shell_quote(cmd)]
    if verbosity > 1:
        cmdlist.append('-v')
    outfile = fileutil.get_single_outfile(outdir, archive)
    cmdlist.extend(['-c', util.shell_quote(archive), '>', util.shell_quote(outfile)])
    return (cmdlist, {'shell': True})



# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Test the lzma program"""

from . import ArchiveTest, Content
from .. import needs_program


class TestLzma(ArchiveTest):
    """Test class for the lzma program"""

    program = 'lzma'

    @needs_program(program)
    def test_lzma(self):
        """Test, extract and create an LZMA archive."""
        self.archive_test('t.txt.lzma')
        self.archive_extract('t.txt.lzma', check=Content.Singlefile)
        self.archive_create('t.txt.lzma', check=Content.Singlefile)

    # file(1) does not recognize .lzma files
    # @needs_program('file')
    # @needs_program(program)
    # def test_lzma_file(self):
    #    self.archive_test('t.lzma.foo')
    #    self.archive_extract('t.lzma.foo')



# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Test the python gzip module"""

from . import ArchiveTest, Content
from .. import needs_program


class TestPygzip(ArchiveTest):
    """Test class for the python gzip module"""

    program = 'py_gzip'

    @needs_program('gzip')
    def test_py_gzip(self):
        """Extract and create GZIP archives."""
        self.archive_extract('t.txt.gz', check=Content.Singlefile)
        # gzip is used to test the created archive
        self.archive_create('t.txt.gz', check=Content.Singlefile)

    @needs_program('file')
    def test_py_gzip_file(self):
        """Extract renamed GZIP archives."""
        self.archive_extract('t.txt.gz.foo', check=Content.Singlefile)
